pub struct StakeSet { /* private fields */ }Expand description
Keeps track of all the active stakes in the blockchain. Abstracts over the pre-TIP911 and post-TIP911 representations.
Implementations
Sourceimpl StakeSet
impl StakeSet
Sourcepub fn add_stake(&mut self, txhash: TxHash, stake: StakeDoc)
pub fn add_stake(&mut self, txhash: TxHash, stake: StakeDoc)
Adds another stake to the set. The transaction hash of the staking transaction, as well as the parsed StakeDoc, must be given.
Sourcepub fn get_stake(&self, txhash: TxHash) -> Option<StakeDoc>
pub fn get_stake(&self, txhash: TxHash) -> Option<StakeDoc>
Gets information about a particular stake, identified by the TxHash of the transaction that created it.
Sourcepub fn is_frozen(&self, coin: CoinID) -> bool
pub fn is_frozen(&self, coin: CoinID) -> bool
Checks whether a particular CoinID is frozen due to it containing an active stake.
Sourcepub fn votes(&self, epoch: u64, key: Ed25519PK) -> u128
pub fn votes(&self, epoch: u64, key: Ed25519PK) -> u128
Checks how many votes a particular staker has, in the given epoch.
Sourcepub fn total_votes(&self, epoch: u64) -> u128
pub fn total_votes(&self, epoch: u64) -> u128
Obtains the number of votes in total for the given epoch.
Sourcepub fn unlock_old(&mut self, epoch: u64)
pub fn unlock_old(&mut self, epoch: u64)
Removes all the stakes that have expired by this epoch.
Sourcepub fn pre_tip911(&self) -> Tree<InMemoryCas>
pub fn pre_tip911(&self) -> Tree<InMemoryCas>
Obtain an old-style (pre-TIP-911) sparse merkle tree that maps the hash of the stdcode encoding of the transaction hash of the transaction that created the stake, to the stdcode-encoded stake.
Sourcepub fn post_tip911(&self, epoch: u64) -> Tip911
pub fn post_tip911(&self, epoch: u64) -> Tip911
Obtain a TIP-911-style object.